@@ -9,7 +9,7 @@ from dbnomics_data_model.storage.adapters.filesystem import FileSystemStorage
 from dbnomics_data_model.storage.errors import StorageError
 from tenacity import Retrying, stop_after_attempt, wait_random_exponential
 
-from dbnomics_solr.dbnomics_solr_client import DatasetAlreadyIndexed, DBnomicsSolrClient, format_datetime
+from dbnomics_solr.dbnomics_solr_client import DatasetAlreadyIndexed, DBnomicsSolrClient, format_date_for_solr
 
 __all__ = ["index_provider"]
 
@@ -28,7 +28,7 @@ def index_provider(
 ):
     """Index data from a provider storage."""
     indexed_at = datetime.now(timezone.utc)
-    logger.debug("Using indexed_at %r for all the Solr documents", format_datetime(indexed_at))
+    logger.debug("Using indexed_at %r for all the Solr documents", format_date_for_solr(indexed_at))
 
     dbnomics_solr_client = DBnomicsSolrClient(solr_url, indexed_at)
 
